FitGridItemsPerPageBreakpoint class

Правило брейкпоинта для вычисления количества элементов на странице.

Constructors

FitGridItemsPerPageBreakpoint({required double minWidth, required double maxWidth, required int maxItemsPerPage})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxItemsPerPage → int
Максимальное количество элементов на странице для указанного диапазона.
final
maxWidth → double
Максимальная ширина (включительно).
final
minWidth → double
Минимальная ширина (включительно).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited