Калькулятор для расчёта количества элементов на странице по ширине области.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
calculateForBreakpoints(
{required double width, required List< FitGridItemsPerPageBreakpoint> breakpoints}) → int -
Рассчитать рекомендуемое значение
maxItemsPerPageпо ширине области на основе произвольного списка брейкпоинтов. -
calculateForPlatformGroup(
{required double width, required FitGridPlatformGroup platformGroup}) → int -
Рассчитать рекомендуемое значение
maxItemsPerPageпо ширине области.